@@ -1,5 +1,5 @@
 package Mongoose;
-$Mongoose::VERSION = '0.39';
+$Mongoose::VERSION = '1.00';
 use MooseX::Singleton;
 use Class::MOP;
 use MongoDB;
@@ -28,11 +28,6 @@ has _args => (
     default => sub{{}}
 );
 
-has _mongodb_v1 => (
-    is      => 'ro',
-    default => sub { version->parse($MongoDB::VERSION) > '0.900' }
-);
-
 has _alias => ( # keep track of aliased() document classes.
     is      => 'rw',
     isa     => 'HashRef',
@@ -140,7 +135,7 @@ sub aliased {
     exists $self->_alias->{$alias} ? $self->_alias->{$alias} : $alias;
 }
 
-1;
+__PACKAGE__->meta->make_immutable();
 
 =head1 NAME
 
@@ -157,17 +152,16 @@ Mongoose - MongoDB document to Moose object mapper
     use Mongoose;
 
     Mongoose->db('mydb');
+
     my $person = Person->new( name => 'Jack' );
     $person->save;
 
-    my $person = Person->find_one( { name => 'Jack' } );
-    say $person->name;    # Jack
+    $person = Person->find_one({ name => 'Jack' });
+    say $person->name; # Jack
 
-    my $cursor = Person->find( { name => 'Jack' } );
-    die "Not found" unless defined $cursor;
-    while ( my $person = $cursor->next ) {
-        say "You're " . $person->name;
-    }
+    Person->find({ name => qr/^J/' })->each(sub{
+        say "Found ", $person->name;
+    });
 
     $person->delete;
 
@@ -186,10 +180,7 @@ Or proceed directly to the L<Mongoose::Cookbook> for many day-to-day recipes.
 
 =head1 WARNING
 
-Since version 0.33 Mongoose support the new L<MongoDB> driver v1.x.x but it still requires
-the old version 0.708.x which will be recomended for some more releases while I keep working
-on the internals. On my initial testing Mongoose is notably faster when running on the old
-version of the driver.
+Since version 0.40 Mongoose only support the new L<MongoDB> driver v1.x.x which it's now required.
 
 Please let me know if you find anything strange using this new driver.
 
